@@ -113,7 +113,7 @@ def runModuleTests(testName, runnableTddModule, times, runSpecificTests, testMod
     #     exception = Exception(f'Not possible to import {testName}')
     #     LogHelper.error(runModuleTests, f'{errorMessage}. Please check warnings for more details', exception)
     #     raise exception
-    dataList = ReflectionHelper.getAttributeDataList(testModule)
+    dataList = ReflectionHelper.getInstanceDataList(testModule)
     LogHelper.prettyPython(runnableTddModule, f'{ReflectionHelper.getName(testModule)} tests loaded', dataList, logLevel=LogHelper.TEST)
     allShouldRun, someShouldRun, allDidRun, someDidRun = getRunStatus(testModule, dataList, runSpecificTests, testModuleNamesToRun)
     testReturns = {}
